@@ -21,7 +21,7 @@ macro_rules! assert_panic {
 		let expected_message = $message;
 		let prev_hook = std::panic::take_hook();
 		std::panic::set_hook(Box::new(|_| {}));
-		let result = std::panic::catch_unwind(|| $code);
+		let result = std::panic::catch_unwind(move || $code);
 		std::panic::set_hook(prev_hook);
 		let err = result
 			.err()
@@ -87,4 +87,13 @@ mod tests {
 		let value = 123;
 		assert_panic!("panic with 123" in panic!("panic with {}", value));
 	}
+
+	#[test]
+	fn supports_mutable_expressions() {
+		let mut list = Vec::new();
+		assert_panic!("bounds" in {
+			list.push(123);
+			let _ = list[1];
+		});
+	}
 }
